filteredASRcounts:
NORMALIZED AND FILTERED ALLELE SPECIFIC READ (ASR) COUNTS FOR AN EXPERIENCE
WITH MORE THAN TWO REPLICATES
Description
A data.frame containing the normalized and filtered values of allele
specific read counts,
for an experiment with more than two replicates. This data.frame is
obtained with the
filterT function run on the normASRcounts
data.frame.
Format
A data.frame.Source
Extract from Bouschet, T. et al. (2016): In vitro corticogenesis from
embryonic stem cells recapitulates the in vivo epigenetic control of
imprinted gene expression. Submitted
Subset of 6062 genes (after filtering).Details
This data.frame is obtained with the filterT function.
Each line represents a feature (e.g. a gene, transcript).
Each column represents the number of allele specific sens reads from
either the paternal or maternal parent for a given biological replicate,
so that you expect to have two columns per biological replicate.
Values in the matrix are filtered and normalized (RLE method) ASR counts.
References
Bouschet, T. et al. (2016): In vitro corticogenesis from embryonic stem cells
recapitulates the in vivo epigenetic control of imprinted gene expression.
Submitted