isolde_test(bias, method = "default", asr_counts, target,
nboot = 5000, pcore = 75, graph = TRUE, ext = "pdf",
text = TRUE, split_files = FALSE, prefix =
"ISoLDE_result", outdir = "")isolde_test to use the threshold method even when more than
three replicates are available. In this case method must be set to
data.frame containing the ASR counts to be tested.
These data should be normalized and filtered (see the filterT
function), although the function can run with non-normalized and
non-filtered data (not recommended).data.frame (obtained by the readTarget
function).method.
Low values of nboot leads to less relevent results (default to 5000).TRUE (default) graphical outputs are produced (both on device and
file).FALSE).
It must be one of TRUE (default) textual output files are produced.TRUE, specifies if your want to have all genes in one same
output file (FALSE, default) or four separate files according to the
result: ASE, biallelic, undetermined or filtered (TRUE).data.frame with one row per gene (or transcript) identified as
having an allelic bias and five columns:
- asr_counts row
names,
- data.frame with one row per gene (or transcript) identified as
biallelically expressed and four columns corresponding to the first four
ones in listASE.data.frame with one row per gene (or transcript) with undetermined
status and six columns. The first five columns are the same as
listASE, the last one may take three values:
- data.frame containing names of genes that have failed the minimal
filtering step and thus that have not been considered during the statistical
test.filterT function for filtering) although the function
can run with non-normalized and/or non-filtered data.
The method depends on your minimum number of replicates for each reciprocal
cross.
If only one replicate is found, the test can not be achieved and exits.
method=# Loading all required data.frames
data(filteredASRcounts)
data(target)
# Statistical analysis (forcing the threshold option)
isolde_res <- isolde_test(bias = "parental", method = "threshold",
asr_counts = filteredASRcounts, target = target, ext = "pdf",
prefix = "ISoLDE_test")Run the code above in your browser using DataLab